.. _artist-api:

*******
artists
*******

.. inheritance-diagram:: matplotlib.patches matplotlib.lines matplotlib.text
   :parts: 2

:mod:`matplotlib.artist`
=============================

.. automodule:: matplotlib.artist
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`matplotlib.lines`
=============================

.. automodule:: matplotlib.lines
   :members:
   :undoc-members:
   :show-inheritance:

:mod:`matplotlib.patches`
=============================

.. automodule:: matplotlib.patches
   :members:
   :undoc-members:
   :show-inheritance:

:mod:`matplotlib.text`
=============================

.. automodule:: matplotlib.text
   :members:
   :undoc-members:
   :show-inheritance:
